@@ -28,17 +28,18 @@
 #include <KSharedConfig>
 #include <KIconUtils>
 
-TopLevel::TopLevel(const KAboutData *aboutData, const QString &icon, QWidget *parent)
+TopLevel::TopLevel(const KAboutData *aboutData, const QString &trayIcon, const QString &notificationIcon, QWidget *parent)
   : QSystemTrayIcon( parent ),
     m_popup(),
-    m_iconName(icon),
+    m_trayIconName(trayIcon),
+    m_notificationIconName(notificationIcon),
     m_runningTeaTime( 0 ),
     m_pausedRemainingTeaTime( 0 ),
     m_nextNotificationTime( 0 )
 {
     repaintTrayIcon(); // Set initial icon
     KSharedConfigPtr config = KSharedConfig::openConfig();
-    KConfigGroup tealistGroup( config, "Tealist" );
+    KConfigGroup tealistGroup( config, QStringLiteral("Tealist")) ;
 
     if( tealistGroup.exists() ) {
         for(unsigned index=0;; ++index) {
@@ -111,10 +112,10 @@ TopLevel::TopLevel(const KAboutData *aboutData, const QString &icon, QWidget *pa
     contextMenu()->addAction( m_actionCollection->action(QStringLiteral("custom")) );
     contextMenu()->addSeparator();
     contextMenu()->addAction( m_actionCollection->action(QStringLiteral("configure")) );
-    contextMenu()->addAction( m_actionCollection->action(QLatin1String(KStandardAction::name(KStandardAction::ConfigureNotifications))) );
+    contextMenu()->addAction( m_actionCollection->action(KStandardAction::name(KStandardAction::ConfigureNotifications)) );
     contextMenu()->addMenu( m_helpMenu->menu() );
     contextMenu()->addSeparator();
-    contextMenu()->addAction( m_actionCollection->action(QLatin1String(KStandardAction::name(KStandardAction::Quit))) );
+    contextMenu()->addAction( m_actionCollection->action(KStandardAction::name(KStandardAction::Quit)) );
 
     m_timer = new QTimer( this );
 
@@ -162,7 +163,7 @@ void TopLevel::setTeaList(const QList<Tea> &tealist) {
 
     // Save list...
     KSharedConfigPtr config = KSharedConfig::openConfig();
-    KConfigGroup tealistGroup( config, "Tealist" );
+    KConfigGroup tealistGroup( config, QStringLiteral("Tealist") );
 
     tealistGroup.deleteGroup();
 
@@ -188,10 +189,10 @@ void TopLevel::setTeaList(const QList<Tea> &tealist) {
     contextMenu()->addAction( m_actionCollection->action(QStringLiteral("custom")) );
     contextMenu()->addSeparator();
     contextMenu()->addAction( m_actionCollection->action(QStringLiteral("configure")) );
-    contextMenu()->addAction( m_actionCollection->action(QLatin1String(KStandardAction::name(KStandardAction::ConfigureNotifications))) );
+    contextMenu()->addAction( m_actionCollection->action(KStandardAction::name(KStandardAction::ConfigureNotifications)) );
     contextMenu()->addMenu(m_helpMenu->menu() );
     contextMenu()->addSeparator();
-    contextMenu()->addAction( m_actionCollection->action(QLatin1String(KStandardAction::name(KStandardAction::Quit))) );
+    contextMenu()->addAction( m_actionCollection->action(KStandardAction::name(KStandardAction::Quit)) );
 
     connect(contextMenu(), &QMenu::triggered, this, &TopLevel::slotRunTea);
 
@@ -258,7 +259,7 @@ void TopLevel::runTea(const Tea &tea)
 
 void TopLevel::repaintTrayIcon()
 {
-    QPixmap icon = QIcon::fromTheme(m_iconName).pixmap(KIconLoader::SizeLarge);
+    QPixmap icon = QIcon::fromTheme(m_trayIconName).pixmap(KIconLoader::SizeLarge);
     if ( m_runningTeaTime <= 0) {
         setIcon(icon);
         return;
@@ -280,7 +281,7 @@ void TopLevel::repaintTrayIcon()
 
         setIcon(icon);
     } else {
-        QPixmap overlayedIcon = KIconUtils::addOverlays(m_iconName, {QStringLiteral( "alarm-symbolic" )}).pixmap(KIconLoader::SizeLarge);
+        QPixmap overlayedIcon = KIconUtils::addOverlays(m_trayIconName, {QStringLiteral( "alarm-symbolic" )}).pixmap(KIconLoader::SizeLarge);
         setIcon(overlayedIcon);
     }
 }
@@ -379,7 +380,7 @@ void TopLevel::configureNotifications()
 void TopLevel::loadConfig()
 {
     KSharedConfigPtr config = KSharedConfig::openConfig();
-    KConfigGroup generalGroup( config, "General" );
+    KConfigGroup generalGroup( config, QStringLiteral("General") );
 
     m_usepopup=generalGroup.readEntry( "UsePopup", true );
     m_autohide=generalGroup.readEntry( "PopupAutoHide", false );
@@ -405,7 +406,7 @@ void TopLevel::showPopup(QSystemTrayIcon::ActivationReason reason)
         m_popup->setComponentName(QStringLiteral("kteatime"));
         m_popup->setTitle(i18n( "The Tea Cooker" ));
         m_popup->setText(toolTip());
-        m_popup->setIconName(m_iconName);
+        m_popup->setIconName(m_notificationIconName);
         m_popup->sendEvent();
     }
 }
